/**
 *  Copyright 2002-2023 Peter Seiderer <Peter.Seiderer@ciselant.de>
 *
 *  This file is part of SeBIE.
 *
 *  SeBIE is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  SeBIE is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with SeBIE; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */
#ifndef _SEBIE_GTK_HELPERS_H_
#define _SEBIE_GTK_HELPERS_H_  1

#include "sebie.h"

GdkPixbuf *
rotate_pixbuf(GdkPixbuf *pixbuf, sebie_rotation rotation);

GdkPixbuf *
pixbuf_color_corrections(GdkPixbuf *pixbuf, double gamma, int grayscale);

#endif /* _SEBIE_VIEW_H_ */
